==> adp_6.0.tar.gz: src/include/Shapes.h <==
# ifndef yyShapes
# define yyShapes

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef bool
# define bool char
# endif

# include "Tree.h"
# include "Definitions.h"

# line 58 "Shapes.puma"


/*********************************************************************
*                                                                    * 
*    struct  shape :   contains the bounds of array expressions      *
*                                                                    *
*     bounds[0] : ug1:og1:str1                                       *
*     bounds[1] : ug2:og2:str2                                       *
*       ....                                                         *
*     bounds[n-1] : ugn:ogn:strn                                     *
*                                                                    *
*********************************************************************/

typedef struct

 { tTree var;                      /* var from which the shape is determined */
   int rank;
   int perm [MAX_DIMENSIONS];      /* permutation vector used in AdaptF77    */
   tTree bounds [MAX_DIMENSIONS] [3]; 
 } struct_shape;

typedef struct_shape* shape;



extern void (* Shapes_Exit) ();

extern void GetFormalShape ARGS((tTree t, shape s));
extern void PrintShape ARGS((shape s));
extern tTree MakeShapedVar ARGS((tTree var, shape shp));
extern tTree NormalizeShape ARGS((tTree t));
extern bool IsWholeVar ARGS((tTree t));
extern tTree MakeFullShape ARGS((tTree t));
extern bool IsContiguousSection ARGS((tTree t));
extern void GetActualShape ARGS((tTree t, shape s));

extern void BeginShapes ();
extern void CloseShapes ();

# endif

==> adp_6.1.tar.gz: src/include/Shapes.h <==
# ifndef yyShapes
# define yyShapes

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 58 "Shapes.puma" */


/*********************************************************************
*                                                                    * 
*    struct  shape :   contains the bounds of array expressions      *
*                                                                    *
*     bounds[0] : ug1:og1:str1                                       *
*     bounds[1] : ug2:og2:str2                                       *
*       ....                                                         *
*     bounds[n-1] : ugn:ogn:strn                                     *
*                                                                    *
*********************************************************************/

typedef struct

 { tTree var;                      /* var from which the shape is determined */
   int rank;
   int perm [MAX_DIMENSIONS];      /* permutation vector used in AdaptF77    */
   tTree bounds [MAX_DIMENSIONS] [3]; 
 } struct_shape;

typedef struct_shape* shape;



extern void (* Shapes_Exit) ARGS ((void));

extern void GetFormalShape ARGS ((tTree t, shape s));
extern void PrintShape ARGS ((shape s));
extern tTree MakeShapedVar ARGS ((tTree var, shape shp));
extern tTree NormalizeShape ARGS ((tTree t));
extern rbool IsWholeVar ARGS ((tTree t));
extern tTree MakeFullShape ARGS ((tTree t));
extern rbool IsContiguousSection ARGS ((tTree t));
extern void GetActualShape ARGS ((tTree t, shape s));

extern void BeginShapes ARGS ((void));
extern void CloseShapes ARGS ((void));

# endif
